@@ -10,9 +10,9 @@ __doc__ = \
 """
 __author__ = "Matteo Ferla. [Github](https://github.com/matteoferla)"
 __email__ = "matteo.ferla@gmail.com"
-__date__ = "2020 A.D."
+__date__ = "25 June 2020 A.D."
 __license__ = "MIT"
-__version__ = "1"
+__version__ = "1.0.4"
 __citation__ = "None."
 
 ########################################################################################################################
@@ -30,6 +30,8 @@ class _PoserMixin:
         :param outfile: optionally save file.
         :return: pose
         """
+
+        self.log.debug(f'Testing params! {outfile}')
         self.dump('_test.params')
         pose = self.__class__.params_to_pose('_test.params', self.NAME)
         os.remove('_test.params')
